@@ -1,4 +1,5 @@
-"""WConsole class."""
+"""WEditCif class."""
+from typing import Callable, NoReturn
 from PyQt5 import QtWidgets, QtCore, QtGui
 
 
@@ -6,7 +7,7 @@ from PyQt5 import QtWidgets, QtCore, QtGui
 class WEditCif(QtWidgets.QTextEdit):
     """WFunction class."""
 
-    def __init__(self, parent=None):
+    def __init__(self, text: str, rewrite_item: Callable, parent=None):
         super(WEditCif, self).__init__(parent)
 
         self.setAcceptRichText(True)
@@ -16,26 +17,16 @@ class WEditCif(QtWidgets.QTextEdit):
         self.setFont(QtGui.QFont("Courier", 8, QtGui.QFont.Normal))
         self.setAlignment(QtCore.Qt.AlignTop)
         self.setStyleSheet("background-color:white;")
+        self.setText(text)
         self.text_changed = False
         self.textChanged.connect(lambda : setattr(self, "text_changed", True))
-        self.object = None
-
-    def set_object(self, obj):
-        """Set object."""
-        self.setText(obj.__repr__())
-        self.setToolTip(obj.__doc__)
-        self.object = obj
-        self.text_changed = False
-
-    def save_object(self):
-        stext = self.toPlainText()
-        obj2 = self.object.from_cif(stext)
-        if obj2 is not None:
-            self.object.copy_from(obj2)
+        self.rewrite_item = rewrite_item
 
     def focusOutEvent(self, event):
         """Submit changes just before focusing out."""
         QtWidgets.QTextEdit.focusOutEvent(self, event)
         if self.text_changed:
-            self.save_object()
-        
\ No newline at end of file
+            s_text = self.toPlainText()
+            self.rewrite_item(s_text)
+            self.text_changed = False
+
